@@ -1,3 +1,6 @@
+#' @importFrom methods setOldClass
+setOldClass("blob")
+
 #' Construct a blob object
 #'
 #' \code{new_blob} is a low-level constructor that takes a list of
@@ -34,6 +37,11 @@ as.blob <- function(x, ...) {
   UseMethod("as.blob")
 }
 
+#' @export
+as.blob.blob <- function(x, ...) {
+  x
+}
+
 #' @export
 as.blob.list <- function(x, ...) {
   new_blob(x)
@@ -53,3 +61,6 @@ as.blob.character <- function(x, ...) {
 as.blob.integer <- function(x, ...) {
   new_blob(lapply(x, as.raw))
 }
+
+#' @export
+as.data.frame.blob <- as.data.frame.difftime
